@@ -21,12 +21,16 @@ from langtrace_python_sdk.utils.with_root_span import (
 )
 
 from langtrace_python_sdk.utils.prompt_registry import get_prompt_from_registry
-from langtrace_python_sdk.utils.with_root_span import SendUserFeedback
+from langtrace_python_sdk.utils.with_root_span import (
+    SendUserFeedback,
+    inject_additional_attributes,
+)
 
 __all__ = [
     "langtrace",
     "with_langtrace_root_span",
     "with_additional_attributes",
+    "inject_additional_attributes",
     "get_prompt_from_registry",
     "SendUserFeedback",
 ]
